<?php
/*
Plugin Name: Creator Five for WooCommerce
Description: Powerful product personalization added to your WooCommerce based shop.
Tags: photo, photobook, print, calendar, ecommerce, card, mug, t-shirt, canvas, collage, poster, w2p, web-to-print
Version: 0.9.5.5
Author: Koffeeware
Author URI: https://www.koffeeware.com
Developer: Carl Conrad
Developer URI: https://www.carlconrad.net/
License: GPL2
Text Domain: creator-five-for-woocommerce
Domain Path: /lang/
*/

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

define( 'C5WOO_VERSION', '0.9.5.5' );

require_once 'config.php';
require_once 'include/functions.php';
require_once 'include/classes.php';
require_once 'init/create_tables.php';
require_once 'init/create_pages.php';

$url = $_SERVER["REQUEST_URI"];

if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
	if ( is_admin() ){
		add_action( 'wp_ajax_add_creations_to_cart', 'c5woo_add_creations_to_cart' );
		add_action( 'wp_ajax_nopriv_add_creations_to_cart', 'c5woo_add_creations_to_cart' );
		add_action( 'wp_ajax_add_prints_to_cart', 'c5woo_add_prints_to_cart' );
		add_action( 'wp_ajax_nopriv_add_prints_to_cart', 'c5woo_add_prints_to_cart' );
		add_action( 'wp_ajax_save_creations_to_account', 'c5woo_save_creations_to_account' );
		add_action( 'wp_ajax_nopriv_save_creations_to_account', 'c5woo_save_creations_to_account' );
		add_action( 'wp_ajax_remove_creations_from_account', 'c5woo_remove_creations_from_account' );
		add_action( 'wp_ajax_nopriv_remove_creations_from_account', 'c5woo_remove_creations_from_account' );

		if ( ! ( get_option( 'wc_C5WOO_settings_endpoint' ) ) )
			require_once( C5WOO_ADMIN_DIR . 'creator-five-settings-missing.php' );

		require_once( C5WOO_ADMIN_DIR . 'woocommerce-settings-tab.php' );
		require_once( C5WOO_ADMIN_DIR . 'woocommerce-status-tab.php' );
		require_once( C5WOO_ADMIN_DIR . 'woocommerce-products-options-attribute.php' );
		require_once( C5WOO_ADMIN_DIR . 'woocommerce-cart-hooks.php' );
	}
	else {
		add_action( 'wp_head', 'c5woo_custom_generator_meta_tag' );
		require_once( C5WOO_PUBLIC_DIR . 'manage-user-account.php' );
		if ( get_option( 'wc_C5WOO_settings_automaticproduction' ) == 'yes')
			require_once( C5WOO_ADMIN_DIR . 'woocommerce-run-builds.php' );

		$isAuthorize = false;
		$isAuthorize = strpos($url, '/authorize/');
		if ($isAuthorize != false) {
			require_once( C5WOO_PUBLIC_DIR . 'create-virtual-page.php' );
		}
		else {
			add_action( 'parse_request', 'C5WOO_parse_request' );
		}
	}
}
else {
	require_once( C5WOO_ADMIN_DIR . 'woocommerce-not-active.php' );
}

function C5WOO_parse_request( &$wp ) {
	if ( !array_key_exists( 'C5WOO_application', $wp->query_vars ) ) {
		require_once( C5WOO_PUBLIC_DIR . 'woocommerce-customize-cart.php' );
		require_once( C5WOO_PUBLIC_DIR . 'woocommerce-product-page.php' );
	}
	else {
		$C5WOO_application = $wp->query_vars['C5WOO_application'];
		switch ($C5WOO_application) {
			case 'creations':
				require_once( C5WOO_PUBLIC_DIR . 'woocommerce-product-personalize-creations-application-page.php' );
				break;
			case 'prints':
				require_once( C5WOO_PUBLIC_DIR . 'woocommerce-product-order-prints-application-page.php' );
				break;
		}
	}
}

add_action('plugins_loaded', 'C5WOO_creatorfive_load_textdomain');
function C5WOO_creatorfive_load_textdomain() {
	load_plugin_textdomain( C5WOO_DOMAIN, false, C5WOO_LANG_DIR );
}

add_filter( 'plugin_action_links', 'wc_C5WOO_plugin_add_settings_link', 10, 5 );
function wc_C5WOO_plugin_add_settings_link( $actions, $plugin_file ) {
	static $plugin;

	if (!isset($plugin))
		$plugin = plugin_basename(__FILE__);
	if ($plugin == $plugin_file) {
		$settings = array('settings' => '<a href="'.admin_url( 'admin.php?page=wc-settings&tab=creatorfive' ).'">'. __( 'Settings' ) .'</a>');
		$actions = array_merge($settings, $actions);
	}
	return $actions;
}

function c5woo_add_creations_to_cart() {
	$product_id  = absint( $_POST['product_id'] );
	$quantity = 1;
	$variation = absint( $_POST['variation_id'] );
	$cart_item_data['productGroup'] = sanitize_text_field( $_POST['product_group'] );
	$cart_item_data['saved_key'] = sanitize_text_field( $_POST['savedkey'] );
	$cart_item_data['thumbnail_url'] = esc_url( $_POST['thumbnailurl'] );
	if ( function_exists( 'WC' ) && ( version_compare( WC()->version, "3.1.0" )>=0)) {
		$cart_item_key = WC()->cart->add_to_cart($product_id, $quantity, $variation, $cart_item_data);
	}
	else {
		global $woocommerce;
		$cart_item_key = $woocommerce->cart->add_to_cart($product_id, $quantity, $variation, $cart_item_data);
	}
	wp_die();
}

function c5woo_add_prints_to_cart() {
	$product_id  = absint( $_POST['product_id'] );
	$quantity = absint( $_POST['quantity'] );
	$variation = absint( $_POST['variation_id'] );
	$cart_item_data['key'] = sanitize_text_field( $_POST['printkey'] );
	$cart_item_data['productGroup'] = sanitize_text_field( $_POST['product_group'] );
	$cart_item_data['descriptor_url'] = esc_url( $_POST['descriptorurl'] );
	$cart_item_data['thumbnail_url'] = esc_url( $_POST['thumbnailurl'] );
	if ( function_exists( 'WC' ) && ( version_compare( WC()->version, "3.1.0" )>=0)) {
		$cart_item_key = WC()->cart->add_to_cart($product_id, $quantity, $variation, $cart_item_data);
	}
	else {
		global $woocommerce;
		$cart_item_key = $woocommerce->cart->add_to_cart($product_id, $quantity, $variation, $cart_item_data);
	}
	wp_die();
}

function c5woo_save_creations_to_account() {
	global $wpdb;
	require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
	$now = date('Y-m-j H:i:s');
	$user_id  = absint( $_POST['user_id'] );
	$product_id  = absint( $_POST['product_id'] );
	$project_id = sanitize_text_field( $_POST['project_id'] );
	$saved_key = sanitize_text_field( $_POST['saved_key'] );
	$variation = absint( $_POST['variation_id'] );
	$thumbnail_url = esc_url( $_POST['thumbnailurl'] );
	$table_name = $wpdb->prefix . 'c5woo_saved_creations';
	$sql = "INSERT INTO $table_name (product_id, project_id, customer_id, creation_time)
		VALUES('$product_id', '$project_id', '$user_id', '$now');";
	dbDelta($sql);
	$table_name = $wpdb->prefix . 'c5woo_saved_creations_versions';
	$sql = "INSERT INTO $table_name (project_id, variation_id, saved_key, thumbnail_url, saved_time)
		VALUES('$project_id', '$variation', '$saved_key', '$thumbnail_url', '$now');";
	dbDelta($sql);
	wp_die();
}

function c5woo_remove_creations_from_account() {
	global $wpdb;
	require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
	$creationid = sanitize_text_field( $_POST['creationid'] );
	$table_name = $wpdb->prefix . 'c5woo_saved_creations';
	$sql = "SELECT id FROM $table_name WHERE project_id = '$creationid';";
	$results = $wpdb->get_results($sql);
	foreach ( $results as $result )  {
		$sql = "DELETE FROM $table_name WHERE id = $result->id;";
		$wpdb->get_results($sql);
	}
	$table_name = $wpdb->prefix . 'c5woo_saved_creations_versions';
	$sql = "SELECT id FROM $table_name WHERE project_id = '$creationid';";
	$results = $wpdb->get_results($sql);
	foreach ( $results as $result )  {
		$sql = "DELETE FROM $table_name WHERE id = $result->id;";
		$wpdb->get_results($sql);
	}
	wp_die();
}

function c5woo_custom_generator_meta_tag() { 
   echo '<meta name="generator" content="Creator Five ' . C5WOO_VERSION . '" />' . "\n";
}

function c5woo_send_maintenance_email($message) {
		$to = 'support@koffeeware.com';
		$subject = 'Creator Five plug-in maintenance';
		$headers = array('Content-Type: text/html; charset=UTF-8');
		wp_mail( $to, $subject, $message, $headers, $attachments );
}